<?php
/**
 * This file is part of the sfContentGetter package.
 * (c) 2006-2007 Jonathan H. Wage <jonwage@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */


/**
 * Get Content
 *
 * Quickly retrieve content from anywhere in symfony. Partial, component, or the result from an action
 * 
 * <code>
 * <?php
 * echo get_content('my_module/_partial');
 * echo get_content('my_module/__component');
 * echo get_content('my_module/___action');
 * // the 'my_module' can be left out and it will inherit the current module
 * ?>
 * </code>
 * 
 * @param mixed $content The content getter string
 * @param array $vars Vars to be passed to the end result content
 * @param mixed $currentModule Current module, needed to make sure the partial can be gotten
 * @access public
 * @return void
 */
function get_content($content, $vars = array(), $currentModule = null)
{
	return sfContentGetter::getInstance($content, $vars, $currentModule)->output();
}

/**
 * Include Content
 *
 * Alias for get_content(); simple calls and echos get_content();
 * 
 * @param mixed $content 
 * @param array $vars 
 * @param mixed $currentModule 
 * @access public
 * @return void
 */
function include_content($content, $vars = array(), $currentModule = null)
{
	echo get_content($content, $vars, $currentModule);
}
?>
